Installation Guide - CKEditor

# CKEditor Installation Guide

### What's CKEditor?

CKEditor is a text editor to be used inside web pages. It's not a replacement for desktop text editors like Word or OpenOffice, but a component to be used as part of web applications and web sites.

### Installation

Installing CKEditor is an easy task. Just follow these simple steps:

1. Download the latest version of the editor from our web site: http://ckeditor.com. You should have already completed this step, but be sure you have the very latest version.
2. Extract (decompress) the downloaded file into the root of your web site.

Note: CKEditor is by default installed in the "ckeditor" folder. You can place the files in whichever you want though.

### Checking Your Installation

The editor comes with a few sample pages that can be used to verify that installation proceeded properly. Take a look at the _samples directory.

To test your installation, just call the following page at your web site:

    http://<your site>/<CKEditor installation path>/_samples/index.html

    For example:
    http://www.example.com/ckeditor/_samples/index.html

### Documentation

The full editor documentation is available online at the following address:
http://docs.cksource.com/ckeditor